package com.ruoyi.ems.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.ems.domain.AdmEmsElecBoxEqptIndex;
import com.ruoyi.ems.mapper.AdmEmsElecBoxEqptIndexMapper;
import com.ruoyi.ems.service.IAdmEmsElecBoxEqptIndexService;

/**
 * 动力箱元器件指标Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-03
 */
@Service
public class AdmEmsElecBoxEqptIndexServiceImpl implements IAdmEmsElecBoxEqptIndexService {
    @Autowired
    private AdmEmsElecBoxEqptIndexMapper admEmsElecBoxEqptIndexMapper;

    /**
     * 查询动力箱元器件指标
     *
     * @param id 动力箱元器件指标主键
     * @return 动力箱元器件指标
     */
    @Override
    public AdmEmsElecBoxEqptIndex selectAdmEmsElecBoxEqptIndexById(Long id) {
        return admEmsElecBoxEqptIndexMapper.selectAdmEmsElecBoxEqptIndexById(id);
    }

    /**
     * 查询动力箱元器件指标列表
     *
     * @param admEmsElecBoxEqptIndex 动力箱元器件指标
     * @return 动力箱元器件指标
     */
    @Override
    public List<AdmEmsElecBoxEqptIndex> selectAdmEmsElecBoxEqptIndexList(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return admEmsElecBoxEqptIndexMapper.selectAdmEmsElecBoxEqptIndexList(admEmsElecBoxEqptIndex);
    }


    @Override
    public List<AdmEmsElecBoxEqptIndex> selectAdmEmsElecBoxEqptLatestIndex(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return admEmsElecBoxEqptIndexMapper.selectAdmEmsElecBoxEqptLatestIndex(admEmsElecBoxEqptIndex);
    }

    /**
     * 新增动力箱元器件指标
     *
     * @param admEmsElecBoxEqptIndex 动力箱元器件指标
     * @return 结果
     */
    @Override
    public int insertAdmEmsElecBoxEqptIndex(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return admEmsElecBoxEqptIndexMapper.insertAdmEmsElecBoxEqptIndex(admEmsElecBoxEqptIndex);
    }

    /**
     * 修改动力箱元器件指标
     *
     * @param admEmsElecBoxEqptIndex 动力箱元器件指标
     * @return 结果
     */
    @Override
    public int updateAdmEmsElecBoxEqptIndex(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return admEmsElecBoxEqptIndexMapper.updateAdmEmsElecBoxEqptIndex(admEmsElecBoxEqptIndex);
    }

    /**
     * 批量删除动力箱元器件指标
     *
     * @param ids 需要删除的动力箱元器件指标主键
     * @return 结果
     */
    @Override
    public int deleteAdmEmsElecBoxEqptIndexByIds(Long[] ids) {
        return admEmsElecBoxEqptIndexMapper.deleteAdmEmsElecBoxEqptIndexByIds(ids);
    }

    /**
     * 删除动力箱元器件指标信息
     *
     * @param id 动力箱元器件指标主键
     * @return 结果
     */
    @Override
    public int deleteAdmEmsElecBoxEqptIndexById(Long id) {
        return admEmsElecBoxEqptIndexMapper.deleteAdmEmsElecBoxEqptIndexById(id);
    }
}
