package com.ruoyi.ems.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.AdmEmsElecBoxEqptIndex;
import com.ruoyi.ems.service.IAdmEmsElecBoxEqptIndexService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 动力箱元器件指标Controller
 *
 * @author ruoyi
 * @date 2024-09-03
 */
@RestController
@RequestMapping("/elecBoxEqptIndex")
public class AdmEmsElecBoxEqptIndexController extends BaseController {
    @Autowired
    private IAdmEmsElecBoxEqptIndexService admEmsElecBoxEqptIndexService;

    /**
     * 查询动力箱元器件指标列表
     */
    @GetMapping("/list")
    public TableDataInfo list(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        startPage();
        List<AdmEmsElecBoxEqptIndex> list = admEmsElecBoxEqptIndexService
            .selectAdmEmsElecBoxEqptIndexList(admEmsElecBoxEqptIndex);
        return getDataTable(list);
    }

    @GetMapping("/latest/list")
    public TableDataInfo latestIndex(AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        startPage();
        List<AdmEmsElecBoxEqptIndex> list = admEmsElecBoxEqptIndexService
            .selectAdmEmsElecBoxEqptLatestIndex(admEmsElecBoxEqptIndex);
        return getDataTable(list);
    }

    /**
     * 导出动力箱元器件指标列表
     */
    @Log(title = "动力箱元器件指标", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        List<AdmEmsElecBoxEqptIndex> list = admEmsElecBoxEqptIndexService
            .selectAdmEmsElecBoxEqptIndexList(admEmsElecBoxEqptIndex);
        ExcelUtil<AdmEmsElecBoxEqptIndex> util = new ExcelUtil<AdmEmsElecBoxEqptIndex>(AdmEmsElecBoxEqptIndex.class);
        util.exportExcel(response, list, "动力箱元器件指标数据");
    }

    /**
     * 获取动力箱元器件指标详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(admEmsElecBoxEqptIndexService.selectAdmEmsElecBoxEqptIndexById(id));
    }

    /**
     * 新增动力箱元器件指标
     */
    @Log(title = "动力箱元器件指标", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return toAjax(admEmsElecBoxEqptIndexService.insertAdmEmsElecBoxEqptIndex(admEmsElecBoxEqptIndex));
    }

    /**
     * 修改动力箱元器件指标
     */
    @Log(title = "动力箱元器件指标", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdmEmsElecBoxEqptIndex admEmsElecBoxEqptIndex) {
        return toAjax(admEmsElecBoxEqptIndexService.updateAdmEmsElecBoxEqptIndex(admEmsElecBoxEqptIndex));
    }

    /**
     * 删除动力箱元器件指标
     */
    @Log(title = "动力箱元器件指标", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(admEmsElecBoxEqptIndexService.deleteAdmEmsElecBoxEqptIndexByIds(ids));
    }
}
